award

# XMLRésuméLibrary: User Guide

author | Element Reference | awards

## Name

award — An award or other honor

## Synopsis

### Content Model

    (title,organization?,(date|period)?,description?)

### Attributes

Name | Type | Default
--- | --- | ---
targets | CDATA | None

## Description

The `award` element describes an award or other honor received by a person (e.g. “Nobel Prize”, “MacArthur Fellow”).

### Parents

`award` may be contained in these elements: `awards`

## Examples

    <award>
      <title>Dean's List</title>
      <organization>ACME University</organization>
    </award>

    <award>
      <title>Honor Roll</title>
      <organization>Littleton Middle School</organization>
      <date>
        <year>1995</year>
      </date>
      <description>
        <para>Maintained a 4.0 GPA.</para>
      </description>
    </award>

author | Element Reference | awards